@@ -1,6 +1,6 @@
 /*
     pmacct (Promiscuous mode IP Accounting package)
-    pmacct is Copyright (C) 2003-2008 by Paolo Lucente
+    pmacct is Copyright (C) 2003-2009 by Paolo Lucente
 */
 
 /*
@@ -533,14 +533,14 @@ int MY_compose_static_queries()
     else {
       if (!config.sql_history_since_epoch) {
 	strncpy(set[set_primitives].string, ", ", SPACELEFT(set[set_primitives].string));
-	strncat(set[set_primitives].string, "stamp_updated=%u", SPACELEFT(set[set_primitives].string));
+	strncat(set[set_primitives].string, "stamp_updated=FROM_UNIXTIME(%u)", SPACELEFT(set[set_primitives].string));
 	set[set_primitives].type = TIMESTAMP;
 	set[set_primitives].handler = count_timestamp_setclause_handler;
 	set_primitives++;
       }
       else {
 	strncpy(set[set_primitives].string, ", ", SPACELEFT(set[set_primitives].string));
-	strncat(set[set_primitives].string, "stamp_updated=UNIX_TIMESTAMP(%u)", SPACELEFT(set[set_primitives].string));
+	strncat(set[set_primitives].string, "stamp_updated=%u", SPACELEFT(set[set_primitives].string));
 	set[set_primitives].type = TIMESTAMP;
 	set[set_primitives].handler = count_timestamp_setclause_handler;
 	set_primitives++;
