@@ -1,6 +1,6 @@
 /*  
     pmacct (Promiscuous mode IP Accounting package)
-    pmacct is Copyright (C) 2003-2008 by Paolo Lucente
+    pmacct is Copyright (C) 2003-2009 by Paolo Lucente
 */
 
 /*
@@ -202,7 +202,7 @@ void process_query_data(int sd, unsigned char *buf, int len, int forked)
 
     /* XXX: we should try using pmct_get_max_entries() */
     q->num = config.classifier_table_num;
-    if (!q->num) q->num = MAX_CLASSIFIERS;
+    if (!q->num && config.classifiers_path) q->num = MAX_CLASSIFIERS;
 
     while (idx < q->num) {
       enQueue_elem(sd, &rb, &class[idx], sizeof(struct stripped_class));
