@@ -383,6 +383,11 @@ inline static void putClass(SFLReceiver *receiver, SFLExtended_classification *c
   put128(receiver, buf);
 }
 
+inline static void putTag(SFLReceiver *receiver, SFLExtended_tag *tag_elem)
+{
+  putNet32(receiver, tag_elem->tag);
+}
+
 inline static void putGenericCounters(SFLReceiver *receiver, SFLIf_counters *counters)
 {
   putNet32(receiver, counters->ifIndex);
@@ -450,6 +455,7 @@ static int computeFlowSampleSize(SFLReceiver *receiver, SFL_FLOW_SAMPLE_TYPE *fs
     case SFLFLOW_EX_MPLS_LDP_FEC: elemSiz = mplsLdpFecEncodingLength(&elem->flowType.mpls_ldp_fec); break;
     case SFLFLOW_EX_VLAN_TUNNEL: elemSiz = vlanTunnelEncodingLength(&elem->flowType.vlan_tunnel); break;
     case SFLFLOW_EX_CLASS: elemSiz = MAX_PROTOCOL_LEN; break;
+    case SFLFLOW_EX_TAG: elemSiz = 4; break;
     default:
       sflError(receiver, "unexpected packet_data_tag");
       return -1;
@@ -577,6 +583,7 @@ int sfl_receiver_writeFlowSample(SFLReceiver *receiver, SFL_FLOW_SAMPLE_TYPE *fs
     case SFLFLOW_EX_MPLS_LDP_FEC: putMplsLdpFec(receiver, &elem->flowType.mpls_ldp_fec); break;
     case SFLFLOW_EX_VLAN_TUNNEL: putVlanTunnel(receiver, &elem->flowType.vlan_tunnel); break;
     case SFLFLOW_EX_CLASS: putClass(receiver, &elem->flowType.class); break;
+    case SFLFLOW_EX_TAG: putTag(receiver, &elem->flowType.tag); break;
     default:
       sflError(receiver, "unexpected packet_data_tag");
       return -1;
